==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-symbol-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
var IgcGeographicSymbolSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicSymbolSeriesComponent, _super);
    function IgcGeographicSymbolSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._assigningScatterStyle = null;
        _this._assigningScatterStyle_wrapped = null;
        _this._assigningScatterMarkerStyle = null;
        _this._assigningScatterMarkerStyle_wrapped = null;
        return _this;
    }
    IgcGeographicSymbolSeriesComponent.prototype.createImplementation = function () {
        return new GeographicSymbolSeries();
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicSymbolSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicSymbolSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = names;
            }
            return IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent.register = function () {
        if (!IgcGeographicSymbolSeriesComponent._isElementRegistered) {
            IgcGeographicSymbolSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicSymbolSeriesComponent.htmlTagName, IgcGeographicSymbolSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "hasOnlyMarkers", {
        /**
         * Gets whether the series has only marker as visuals
        */
        get: function () {
            return this.i.dy;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "latitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get: function () {
            return this.i.vr;
        },
        set: function (v) {
            this.i.vr = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "longitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get: function () {
            return this.i.vt;
        },
        set: function (v) {
            this.i.vt = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: function () {
            return this.i.vd;
        },
        set: function (v) {
            this.i.vd = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.vd));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "isCustomScatterStyleAllowed", {
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get: function () {
            return this.i.vk;
        },
        set: function (v) {
            this.i.vk = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.vk);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "isCustomScatterMarkerStyleAllowed", {
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get: function () {
            return this.i.vj;
        },
        set: function (v) {
            this.i.vj = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.vj);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "itemSearchMode", {
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get: function () {
            return this.i.ve;
        },
        set: function (v) {
            this.i.ve = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.ve));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "itemSearchThreshold", {
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get: function () {
            return this.i.vm;
        },
        set: function (v) {
            this.i.vm = +v;
            this._a("itemSearchThreshold", this.i.vm);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "assigningScatterStyle", {
        /**
         * Event raised when Assigning Category Style
        */
        get: function () {
            return this._assigningScatterStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = function (o, e) {
                var outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningScatterStyle) {
                    _this.beforeAssigningScatterStyle(_this, outerArgs);
                }
                if (_this._assigningScatterStyle) {
                    _this._assigningScatterStyle(_this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "assigningScatterMarkerStyle", {
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get: function () {
            return this._assigningScatterMarkerStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = function (o, e) {
                var outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningScatterMarkerStyle) {
                    _this.beforeAssigningScatterMarkerStyle(_this, outerArgs);
                }
                if (_this._assigningScatterMarkerStyle) {
                    _this._assigningScatterMarkerStyle(_this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = null;
    IgcGeographicSymbolSeriesComponent.htmlTagName = "igc-geographic-symbol-series";
    IgcGeographicSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicSymbolSeriesComponent;
}(IgcGeographicMarkerSeriesComponent));
export { IgcGeographicSymbolSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-symbol-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { CollisionAvoidanceType_$type } from "igniteui-webcomponents-charts";
import { ScatterItemSearchMode_$type } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcAssigningScatterMarkerStyleEventArgs } from "igniteui-webcomponents-charts";
import { IgcGeographicMarkerSeriesComponent } from "./igc-geographic-marker-series-component";
import { GeographicSymbolSeries } from "./GeographicSymbolSeries";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class for a geographic map with points marked at given locations.
 * This is the geographic equivalent of a ScatterSeries.
*/
var IgcGeographicSymbolSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicSymbolSeriesComponent, _super);
    function IgcGeographicSymbolSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._assigningScatterStyle = null;
        _this._assigningScatterStyle_wrapped = null;
        _this._assigningScatterMarkerStyle = null;
        _this._assigningScatterMarkerStyle_wrapped = null;
        return _this;
    }
    IgcGeographicSymbolSeriesComponent.prototype.createImplementation = function () {
        return new GeographicSymbolSeries();
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicSymbolSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicSymbolSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = names;
            }
            return IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent.register = function () {
        if (!IgcGeographicSymbolSeriesComponent._isElementRegistered) {
            IgcGeographicSymbolSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicSymbolSeriesComponent.htmlTagName, IgcGeographicSymbolSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "hasOnlyMarkers", {
        /**
         * Gets whether the series has only marker as visuals
        */
        get: function () {
            return this.i.ej;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "latitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the latitude coordinate of the symbol.
        */
        get: function () {
            return this.i.yo;
        },
        set: function (v) {
            this.i.yo = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "longitudeMemberPath", {
        /**
         * The name of the property of ItemsSource items which contains the longitude coordinate of the symbol.
        */
        get: function () {
            return this.i.yq;
        },
        set: function (v) {
            this.i.yq = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "markerCollisionAvoidance", {
        /**
         * The desired behavior for markers in this series which are placed too close together for the current view, resulting in a collision.
        */
        get: function () {
            return this.i.ya;
        },
        set: function (v) {
            this.i.ya = ensureEnum(CollisionAvoidanceType_$type, v);
            this._a("markerCollisionAvoidance", enumToString(CollisionAvoidanceType_$type, this.i.ya));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "isCustomScatterStyleAllowed", {
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual visuals.
        */
        get: function () {
            return this.i.yh;
        },
        set: function (v) {
            this.i.yh = ensureBool(v);
            this._a("isCustomScatterStyleAllowed", this.i.yh);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "isCustomScatterMarkerStyleAllowed", {
        /**
         * Gets or sets whether this Scatter series should allow custom style overrides of its individual marker visuals.
        */
        get: function () {
            return this.i.yg;
        },
        set: function (v) {
            this.i.yg = ensureBool(v);
            this._a("isCustomScatterMarkerStyleAllowed", this.i.yg);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "itemSearchMode", {
        /**
         * Gets or sets the mode the series will use to find the closest point to the cursor.
        */
        get: function () {
            return this.i.yb;
        },
        set: function (v) {
            this.i.yb = ensureEnum(ScatterItemSearchMode_$type, v);
            this._a("itemSearchMode", enumToString(ScatterItemSearchMode_$type, this.i.yb));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "itemSearchThreshold", {
        /**
         * Gets or sets the threshold to use when searching for items using ItemSearchMode.
        */
        get: function () {
            return this.i.yj;
        },
        set: function (v) {
            this.i.yj = +v;
            this._a("itemSearchThreshold", this.i.yj);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "assigningScatterStyle", {
        /**
         * Event raised when Assigning Category Style
        */
        get: function () {
            return this._assigningScatterStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningScatterStyle_wrapped !== null) {
                this.i.assigningScatterStyle = delegateRemove(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
                this._assigningScatterStyle_wrapped = null;
                this._assigningScatterStyle = null;
            }
            this._assigningScatterStyle = ev;
            this._assigningScatterStyle_wrapped = function (o, e) {
                var outerArgs = new IgcAssigningScatterStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningScatterStyle) {
                    _this.beforeAssigningScatterStyle(_this, outerArgs);
                }
                if (_this._assigningScatterStyle) {
                    _this._assigningScatterStyle(_this, outerArgs);
                }
            };
            this.i.assigningScatterStyle = delegateCombine(this.i.assigningScatterStyle, this._assigningScatterStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicSymbolSeriesComponent.prototype, "assigningScatterMarkerStyle", {
        /**
         * Event raised when Assigning Scatter Marker Style
        */
        get: function () {
            return this._assigningScatterMarkerStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningScatterMarkerStyle_wrapped !== null) {
                this.i.assigningScatterMarkerStyle = delegateRemove(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
                this._assigningScatterMarkerStyle_wrapped = null;
                this._assigningScatterMarkerStyle = null;
            }
            this._assigningScatterMarkerStyle = ev;
            this._assigningScatterMarkerStyle_wrapped = function (o, e) {
                var outerArgs = new IgcAssigningScatterMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningScatterMarkerStyle) {
                    _this.beforeAssigningScatterMarkerStyle(_this, outerArgs);
                }
                if (_this._assigningScatterMarkerStyle) {
                    _this._assigningScatterMarkerStyle(_this, outerArgs);
                }
            };
            this.i.assigningScatterMarkerStyle = delegateCombine(this.i.assigningScatterMarkerStyle, this._assigningScatterMarkerStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicSymbolSeriesComponent._observedAttributesIgcGeographicSymbolSeriesComponent = null;
    IgcGeographicSymbolSeriesComponent.htmlTagName = "igc-geographic-symbol-series";
    IgcGeographicSymbolSeriesComponent._isElementRegistered = false;
    return IgcGeographicSymbolSeriesComponent;
}(IgcGeographicMarkerSeriesComponent));
export { IgcGeographicSymbolSeriesComponent };
